@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-'''
+"""
 
   canteen
   ~~~~~~~
@@ -13,13 +13,25 @@
             A copy of this license is included as ``LICENSE.md`` in
             the root of the project.
 
-'''
+"""
 
-debug, __version__ = __debug__, (1, 0)
+debug, __version__ = __debug__, (0, 3)
 
 # stdlib
 import __builtin__; export = None
 
+# yay modules!
+from . import core
+from . import rpc
+from . import util
+from . import test
+from . import base
+from . import model
+from . import logic
+from . import runtime
+from . import dispatch
+from . import exceptions
+
 # canteen :)
 from .rpc import *
 from .core import *
@@ -33,4 +45,6 @@ from .dispatch import *
 from .exceptions import *
 
 
-__all__ = [export for export in globals() if (export not in __builtin__.__dict__ and (not export.startswith('__')))]  # export all the things!
+__all__ = [export for export in globals() if (
+  export not in __builtin__.__dict__ and (
+    not export.startswith('__')))]  # export all the things!
